<h1 align="center">Welcome to corebodytemp 👋</h1>
<p>
  <img alt="Version" src="https://img.shields.io/badge/version-0.1.0-blue.svg?cacheSeconds=2592000" />
  <a href="https://github.com/purpl3F0x/corebodytemp/blob/master/README.md" target="_blank">
    <img alt="License: MIT" src="https://img.shields.io/badge/License-MIT-yellow.svg" />
  </a>
</p>

> Python BLE API for interacting with CoreBodyTemp Sensors

### 🏠 [Homepage](https://github.com/purpl3F0x/corebodytemp)

## Install

```sh
pip install corebodytemp
```

## Author

👤 **Stavros Avramidis**

* Github: [@purpl3F0x](https://github.com/purpl3F0x)

## Show your support

Give a ⭐️ if this project helped you!

## 📝 License

Copyright © 2022 [Stavros Avramidis](https://github.com/purpl3F0x).<br />
This project is [MIT](https://github.com/purpl3F0x/corebodytemp/blob/master/README.md) licensed.

***
